@@ -5,6 +5,10 @@ use warnings;
 require Exporter;
 require DynaLoader;
 our @ISA = qw(Exporter DynaLoader);
+
+use SDL::Internal::Loader;
+internal_load_dlls(__PACKAGE__);
+
 bootstrap SDL::Palette;
 
 1;
