@@ -4,8 +4,10 @@ use warnings;
 require Exporter;
 require DynaLoader;
 our @ISA = qw(Exporter DynaLoader);
+
+use SDL::Internal::Loader;
+internal_load_dlls(__PACKAGE__);
+
 bootstrap SDL::TTF_Font;
 
 1;
-
-__END__
\ No newline at end of file
